@@ -12,20 +12,20 @@ class BaseVISPDataset(Spec214Dataset):
     """
 
     def __init__(self,
-                 n_raster,
-                 n_scans,
+                 n_maps,
+                 n_steps,
                  n_stokes,
                  time_delta,
                  *,
                  linewave,
                  detector_shape=(4096, 4096)):
 
-        if (not n_raster) or (not n_scans):
+        if (not n_maps) or (not n_steps):
             raise NotImplementedError("Support for less than 4D VISP datasets is not implemented.")
 
         array_shape = [1] + list(detector_shape)
 
-        dataset_shape_rev = list(detector_shape) + [n_raster, n_scans]
+        dataset_shape_rev = list(detector_shape) + [n_maps, n_steps]
         if n_stokes:
             dataset_shape_rev += [n_stokes]
 
