@@ -34,14 +34,14 @@ class DatasetTest214(Spec214Dataset):
                    array_shape=(40, 50),
                    time_delta=10
                    ),
-    SimpleVISPDataset(n_raster=2,
-                      n_scans=3,
+    SimpleVISPDataset(n_maps=2,
+                      n_steps=3,
                       n_stokes=4,
                       time_delta=10,
                       linewave=500 * u.m
                       ),
-    SimpleVISPDataset(n_raster=2,
-                      n_scans=3,
+    SimpleVISPDataset(n_maps=2,
+                      n_steps=3,
                       n_stokes=0,
                       time_delta=10,
                       linewave=500 * u.m
@@ -97,8 +97,9 @@ def test_generate_214(ds):
     filenames = [f"{i}.fits" for i in range(len(headers))]
     table_headers, _, sorted_headers = sort_headers(headers, filenames)
 
-    wcs = TransformBuilder(sorted_headers).gwcs
+    tb = TransformBuilder(sorted_headers)
+    wcs = tb.gwcs
     assert isinstance(wcs, gwcs.WCS)
 
-    inv = extract_inventory(table_headers, wcs)
+    inv = extract_inventory(table_headers, tb)
     assert isinstance(inv, dict)
