@@ -3,6 +3,7 @@
 import io
 from pathlib import Path
 
+from astropy.io import fits
 import numpy as np
 import pytest  # type: ignore
 
@@ -118,7 +119,8 @@ def test_generate_headers(dataset_5d):
         return ds.file_index[3 - ind]
     dataset_5d.add_generator_function(("DINDEX1", "DINDEX2", "DINDEX3"), make_index)
 
-    headers = dataset_5d.generate_headers()
+    with pytest.warns(UserWarning):
+        headers = dataset_5d.generate_headers()
 
     assert len(headers) == dataset_5d.n_files
 
@@ -139,5 +141,32 @@ def test_generate_file_bytes_io(dataset_1d):
         fobj = ds.file(io.BytesIO())
 
         assert isinstance(fobj, io.BytesIO)
-        fobj.seek(0)
         assert fobj.read(6) == b"SIMPLE"
+
+
+def test_generate_hdu_uncompressed(dataset_1d):
+    dataset_1d.add_constant_key("INSTRUME", "CADAIR")
+
+    for ds in dataset_1d:
+        hdu = ds.hdu()
+        assert isinstance(hdu, fits.PrimaryHDU)
+        assert hdu.header['INSTRUME'] == "CADAIR"
+
+
+def test_generate_hdu_compressed(dataset_1d):
+    dataset_1d.add_constant_key("INSTRUME", "CADAIR")
+
+    for ds in dataset_1d:
+        hdu = ds.hdu(rice_compress=True)
+        assert isinstance(hdu, fits.CompImageHDU)
+        assert hdu.header['INSTRUME'] == "CADAIR"
+
+
+def test_generate_hdu_compressed_kwargs(dataset_1d):
+    dataset_1d.add_constant_key("INSTRUME", "CADAIR")
+
+    for ds in dataset_1d:
+        hdu = ds.hdu(rice_compress={"compression_type": "GZIP_1"})
+        assert isinstance(hdu, fits.CompImageHDU)
+        assert hdu.header["INSTRUME"] == "CADAIR"
+        assert hdu._header["ZCMPTYPE"] == "GZIP_1"
